pub struct SyncConfig {
pub interval_ms: u64,
pub idle_interval_ms: Option<u64>,
pub max_batch_size: usize,
pub min_bytes: usize,
}Fields
interval_ms: u64Maximum time to wait before syncing to disk (milliseconds)
idle_interval_ms: Option<u64>Maximum time to wait before syncing to disk when idle (milliseconds)
max_batch_size: usizeMaximum number of events to batch before syncing
min_bytes: usizeMinimum bytes to accumulate before syncing